/*
 * Purpose: Helper class for sorting and changing columns
 * Author:  Frank Bu
 * Created: 2002
 */

#ifndef COLUMN_FIELD_H
#define COLUMN_FIELD_H

/**
 * Helper class for table sort and column change functionality.
 */
class ColumnField
{
public:
	/**
	 * Creates a new column.
	 * \param name Column label.
	 * \param oldIndex Reference to the current table column. -1 for new columns.
	 * \param oldWidth Reference to the current tabel column width, specified by oldIndex.
	 */
	ColumnField(wxString name, int oldIndex = -1, int oldWidth = 0);

	/**
	 * Tests if the columns is new for the column change functionality.
	 * \return true, if the column is new.
	 */
	bool isNew();

	/**
	 * Gets the index of the current table column, for column change functionality.
	 */
	int getOldIndex();

	/**
	 * Gets the with of the current table column, for column change functionality.
	 */
	int getOldWidth();

	/**
	 * Gets the column label, perhaps changed by the column change dialog.
	 */
	wxString getName();

	/**
	 * Sets a new column label.
	 */
	void setName(wxString name);

private:
	wxString m_name;
	int m_oldIndex;
	int m_oldWidth;
};

/**
 * Helper class for the column sort functionality.
 * An object of this class is the first entry in the column
 * wxChoice control of the SortDialog for choosing nothing.
 */
class NullColumnField : public ColumnField
{
public:
	NullColumnField() : ColumnField("(keine)") {}
};

#endif  // COLUMN_FIELD_H
